@@ -19,8 +19,9 @@ from playwright_helper.utils.type_utils import RunResult
 from playwright_helper.utils.log_utils import logger as log
 from playwright_helper.libs.browser_pool import BrowserPool
 from playwright_helper.utils.file_handle import get_caller_dir
-from playwright.async_api import Page, Browser, BrowserContext
-from typing import Any, List, Optional, cast, Callable, Literal
+from typing import Any, List, Optional, cast, Callable, Literal, Dict
+from playwright.async_api import Page, Browser, BrowserContext, TimeoutError as PlaywrightTimeoutError, \
+    Error as PlaywrightError
 
 
 class PlaywrightBrowserExecutor:
@@ -37,7 +38,7 @@ class PlaywrightBrowserExecutor:
             video_dir: str = None,
             trace_dir: str = None,
             screenshot_dir: str = None,
-            storage_state: Optional[str] = None,
+            storage_state: Optional[Dict[str, Any]] = None,
             **browser_config: Any,
     ):
         self.mode = mode
@@ -122,12 +123,23 @@ class PlaywrightBrowserExecutor:
         return context
 
     async def _cleanup_context(self, context: BrowserContext):
-        await context.close()
+        if getattr(context, "_closed", False):
+            return
+
+        context._closed = True  # type: ignore
+
+        try:
+            await context.close()
+        except Exception as e:
+            self.logger.debug(f"[Cleanup] ignore close error: {e}")
 
         browser = getattr(context, "_browser", None)
         if browser:
-            self.logger.debug("[Executor] Release browser to pool")
-            await self.browser_pool.release(browser)
+            try:
+                self.logger.debug("[Executor] Release browser to pool")
+                await self.browser_pool.release(browser)
+            except Exception as e:
+                self.logger.error(f"[Cleanup] ignore release error: {e}")
 
     async def _run_callback_chain(self, *, callback: Callable, page: Page, context: BrowserContext, **kwargs) -> Any:
         # Run middlewares before callback
@@ -167,25 +179,23 @@ class PlaywrightBrowserExecutor:
                 self.logger.warning(f"[Task<{task_id}> Cancelled]")
 
                 # 清理资源
-                if context:
-                    await self._cleanup_context(context)
-                    if self.record_trace:
-                        os.makedirs(self.trace_dir, exist_ok=True)
-                        trace_path = os.path.join(self.trace_dir, f"{task_id}.zip")
-                        await context.tracing.stop(path=trace_path)
-                        self.logger.error(f"[Trace Saved] {trace_path}")
+                if context and self.record_trace:
+                    os.makedirs(self.trace_dir, exist_ok=True)
+                    trace_path = os.path.join(self.trace_dir, f"{task_id}.zip")
+                    await context.tracing.stop(path=trace_path)
+                    self.logger.error(f"[Trace Saved] {trace_path}")
 
                 # ❗关键：不要 raise
                 return RunResult(
                     success=False,
-                    attempts=attempt,
+                    attempts=attempt + 1,
                     error=asyncio.CancelledError(),
                     task_id=task_id,
                     result=result
                 )
-            except Exception as e:
+            except (PlaywrightTimeoutError, PlaywrightError, Exception) as e:
                 last_error = e
-                self.logger.error(f"[Task<{task_id}> Attempt {attempt} Failed] {e}")
+                self.logger.error(f"[Task<{task_id}> Attempt {attempt + 1} Failed] {e}")
                 if page:
                     await self._safe_screenshot(page=page, name=task_id)
 
